@@ -10,13 +10,12 @@ use IPC::Cmd qw/run/;
 use Carp qw/croak/;
 use ExtUtils::MakeMaker qw/prompt/;
 use File::Which qw/which/;
-use HTTP::Tinyish;
 use JSON::PP qw/decode_json/;
 use Path::Tiny qw/path/;
 use POSIX qw(setlocale LC_TIME);
 use Scope::Guard qw/guard/;
 use Time::Piece qw/localtime/;
-use version; our $VERSION = version->declare("v0.0.1");
+use version; our $VERSION = version->declare("v0.0.2");
 
 use parent 'Exporter';
 
@@ -39,10 +38,6 @@ sub hub {
     unshift @_, $com; goto \&command;
 }
 
-sub http_get {
-    HTTP::Tinyish->new->get(shift);
-}
-
 # file utils
 sub slurp {
     path(shift)->slurp_utf8
@@ -133,6 +128,7 @@ sub update_versions {
         $content =~ s/^(Version:\s+)$cur_ver_reg/$1$next_version/ms;
         $content;
     };
+    command qw/gobump set/, $next_version, '-w';
 }
 
 sub update_changelog {
@@ -211,7 +207,7 @@ sub create_release_pull_request {
 
     my @releases = merged_prs $current_version;
     infof "bump versions and update documents\n";
-    update_versions $package_name, $next_version;
+    update_versions $package_name, $current_version, $next_version;
     update_changelog $package_name, $next_version, @releases;
     # main process
     $code->($current_version, $next_version, [@releases]) if $code;
